@@ -18,20 +18,22 @@
 #include <utils/applicationstate.h>
 #include <utils/filedialog.h>
 
+#include <Libkleo/Algorithm>
 #include <Libkleo/Classify>
 #include <Libkleo/Formatting>
+#include <Libkleo/KeyHelpers>
 
-#include <QGpgME/Protocol>
 #include <QGpgME/ExportJob>
+#include <QGpgME/Protocol>
 
 #include <gpgme++/key.h>
 
 #include <KLocalizedString>
 #include <QSaveFile>
 
+#include <QFileInfo>
 #include <QMap>
 #include <QPointer>
-#include <QFileInfo>
 
 #include <algorithm>
 #include <vector>
@@ -47,6 +49,7 @@ class ExportCertificateCommand::Private : public Command::Private
     {
         return static_cast<ExportCertificateCommand *>(q);
     }
+
 public:
     explicit Private(ExportCertificateCommand *qq, KeyListController *c);
     ~Private() override;
@@ -55,6 +58,7 @@ public:
     void exportResult(const GpgME::Error &, const QByteArray &);
     void showError(const GpgME::Error &error);
 
+    bool confirmExport(const std::vector<Key> &pgpKeys);
     bool requestFileNames(GpgME::Protocol prot);
     void finishedIfLastJob();
 
@@ -81,30 +85,30 @@ const ExportCertificateCommand::Private *ExportCertificateCommand::d_func() cons
 ExportCertificateCommand::Private::Private(ExportCertificateCommand *qq, KeyListController *c)
     : Command::Private(qq, c)
 {
-
 }
 
-ExportCertificateCommand::Private::~Private() {}
+ExportCertificateCommand::Private::~Private()
+{
+}
 
 ExportCertificateCommand::ExportCertificateCommand(KeyListController *p)
     : Command(new Private(this, p))
 {
-
 }
 
 ExportCertificateCommand::ExportCertificateCommand(QAbstractItemView *v, KeyListController *p)
     : Command(v, new Private(this, p))
 {
-
 }
 
 ExportCertificateCommand::ExportCertificateCommand(const Key &key)
     : Command(key, new Private(this, nullptr))
 {
-
 }
 
-ExportCertificateCommand::~ExportCertificateCommand() {}
+ExportCertificateCommand::~ExportCertificateCommand()
+{
+}
 
 void ExportCertificateCommand::setOpenPGPFileName(const QString &fileName)
 {
@@ -132,32 +136,77 @@ QString ExportCertificateCommand::x509FileName() const
 
 void ExportCertificateCommand::doStart()
 {
-    std::vector<Key> keys = d->keys();
-    if (keys.empty()) {
+    if (d->keys().empty()) {
+        d->finished();
         return;
     }
 
-    const auto firstCms = std::partition(keys.begin(), keys.end(),
-                                         [](const GpgME::Key &key) {
-                                            return key.protocol() != GpgME::CMS;
-                                         });
-    std::vector<Key> openpgp, cms;
-    std::copy(keys.begin(), firstCms, std::back_inserter(openpgp));
-    std::copy(firstCms, keys.end(), std::back_inserter(cms));
-    Q_ASSERT(!openpgp.empty() || !cms.empty());
-    const bool haveBoth = !cms.empty() && !openpgp.empty();
-    const GpgME::Protocol prot = haveBoth ? UnknownProtocol : (!cms.empty() ? CMS : OpenPGP);
+    const auto keys = Kleo::partitionKeysByProtocol(d->keys());
+
+    if (!keys.openpgp.empty() && !d->confirmExport(keys.openpgp)) {
+        d->canceled();
+        return;
+    }
+
+    const bool haveBoth = !keys.cms.empty() && !keys.openpgp.empty();
+    const GpgME::Protocol prot = haveBoth ? UnknownProtocol : (!keys.cms.empty() ? CMS : OpenPGP);
     if (!d->requestFileNames(prot)) {
-        Q_EMIT canceled();
-        d->finished();
-    } else {
-        if (!openpgp.empty()) {
-            d->startExportJob(GpgME::OpenPGP, openpgp);
+        d->canceled();
+        return;
+    }
+
+    if (!keys.openpgp.empty()) {
+        d->startExportJob(GpgME::OpenPGP, keys.openpgp);
+    }
+    if (!keys.cms.empty()) {
+        d->startExportJob(GpgME::CMS, keys.cms);
+    }
+}
+
+bool ExportCertificateCommand::Private::confirmExport(const std::vector<Key> &pgpKeys)
+{
+    auto notCertifiedKeys = std::accumulate(pgpKeys.cbegin(), pgpKeys.cend(), QStringList{}, [](auto keyNames, const auto &key) {
+        const bool allValidUserIDsAreCertifiedByUser = Kleo::all_of(key.userIDs(), [](const UserID &userId) {
+            return userId.isBad() || Kleo::userIDIsCertifiedByUser(userId);
+        });
+        if (!allValidUserIDsAreCertifiedByUser) {
+            keyNames.push_back(Formatting::formatForComboBox(key));
         }
-        if (!cms.empty()) {
-            d->startExportJob(GpgME::CMS, cms);
+        return keyNames;
+    });
+    if (!notCertifiedKeys.empty()) {
+        if (pgpKeys.size() == 1) {
+            const auto answer = KMessageBox::warningContinueCancel( //
+                parentWidgetOrView(),
+                xi18nc("@info",
+                       "<para>You haven't certified all valid user IDs of this certificate "
+                       "with an exportable certification. People relying on your certifications "
+                       "may not be able to verify the certificate.</para>"
+                       "<para>Do you want to continue the export?</para>"),
+                i18nc("@title:window", "Confirm Certificate Export"),
+                KGuiItem{i18ncp("@action:button", "Export Certificate", "Export Certificates", 1)},
+                KStandardGuiItem::cancel(),
+                QStringLiteral("confirm-export-of-uncertified-keys"));
+            return answer == KMessageBox::Continue;
+        } else {
+            std::sort(notCertifiedKeys.begin(), notCertifiedKeys.end());
+            const auto answer = KMessageBox::warningContinueCancelList( //
+                parentWidgetOrView(),
+                xi18nc("@info",
+                       "<para>You haven't certified all valid user IDs of the certificates listed below "
+                       "with exportable certifications. People relying on your certifications "
+                       "may not be able to verify the certificates.</para>"
+                       "<para>Do you want to continue the export?</para>"),
+                notCertifiedKeys,
+                i18nc("@title:window", "Confirm Certificate Export"),
+                KGuiItem{i18ncp("@action:button", "Export Certificate", "Export Certificates", pgpKeys.size())},
+                KStandardGuiItem::cancel(),
+                QStringLiteral("confirm-export-of-uncertified-keys"));
+            return answer == KMessageBox::Continue;
         }
     }
+
+    return true;
 }
 
 bool ExportCertificateCommand::Private::requestFileNames(GpgME::Protocol protocol)
@@ -189,12 +238,12 @@ bool ExportCertificateCommand::Private::requestFileNames(GpgME::Protocol protoco
         if (name.isEmpty()) {
             name = Formatting::prettyEMail(key);
         }
+        const auto asciiArmoredCertificateClass = (protocol == OpenPGP ? Class::OpenPGP : Class::CMS) | Class::Ascii | Class::Certificate;
         /* Not translated so it's better to use in tutorials etc. */
-        proposedFileName += QStringLiteral("%1_%2_public.%3").arg(name).arg(
-                Formatting::prettyKeyID(key.shortKeyID())).arg(
-                QString::fromLatin1(outputFileExtension(protocol == OpenPGP
-                        ? Class::OpenPGP | Class::Ascii | Class::Certificate
-                        : Class::CMS | Class::Ascii | Class::Certificate, usePGPFileExt)));
+        proposedFileName += QStringLiteral("%1_%2_public.%3")
+                                .arg(name)
+                                .arg(Formatting::prettyKeyID(key.shortKeyID()))
+                                .arg(outputFileExtension(asciiArmoredCertificateClass, usePGPFileExt));
     }
     if (protocol == GpgME::CMS) {
         if (!fileNames[GpgME::OpenPGP].isEmpty()) {
@@ -218,17 +267,16 @@ bool ExportCertificateCommand::Private::requestFileNames(GpgME::Protocol protoco
     }
 
     auto fname = FileDialog::getSaveFileNameEx(parentWidgetOrView(),
-                          i18nc("1 is protocol", "Export %1 Certificates", Formatting::displayName(protocol)),
-                          QStringLiteral("imp"),
-                          proposedFileName,
-                          protocol == GpgME::OpenPGP
-                          ? i18n("OpenPGP Certificates") + QLatin1String(" (*.asc *.gpg *.pgp)")
-                          : i18n("S/MIME Certificates")  + QLatin1String(" (*.pem *.der)"));
+                                               i18nc("1 is protocol", "Export %1 Certificates", Formatting::displayName(protocol)),
+                                               QStringLiteral("imp"),
+                                               proposedFileName,
+                                               protocol == GpgME::OpenPGP ? i18n("OpenPGP Certificates") + QLatin1String(" (*.asc *.gpg *.pgp)")
+                                                                          : i18n("S/MIME Certificates") + QLatin1String(" (*.pem *.der)"));
 
     if (!fname.isEmpty() && protocol == GpgME::CMS && fileNames[GpgME::OpenPGP] == fname) {
         KMessageBox::error(parentWidgetOrView(),
-                         i18n("You have to select different filenames for different protocols."),
-                         i18n("Export Error"));
+                           i18n("You have to select different filenames for different protocols."),
+                           i18nc("@title:window", "Export Error"));
         return false;
     }
     const QFileInfo fi(fname);
@@ -249,8 +297,8 @@ void ExportCertificateCommand::Private::startExportJob(GpgME::Protocol protocol,
     Q_ASSERT(backend);
     const QString fileName = fileNames[protocol];
     const bool binary = protocol == GpgME::OpenPGP
-                        ? fileName.endsWith(QLatin1String(".gpg"), Qt::CaseInsensitive) || fileName.endsWith(QLatin1String(".pgp"), Qt::CaseInsensitive)
-                        : fileName.endsWith(QLatin1String(".der"), Qt::CaseInsensitive);
+        ? fileName.endsWith(QLatin1String(".gpg"), Qt::CaseInsensitive) || fileName.endsWith(QLatin1String(".pgp"), Qt::CaseInsensitive)
+        : fileName.endsWith(QLatin1String(".der"), Qt::CaseInsensitive);
     std::unique_ptr<ExportJob> job(backend->publicKeyExportJob(!binary));
     Q_ASSERT(job.get());
 
@@ -258,13 +306,7 @@ void ExportCertificateCommand::Private::startExportJob(GpgME::Protocol protocol,
         exportResult(result, keyData);
     });
 
-#if QGPGME_JOB_HAS_NEW_PROGRESS_SIGNALS
-    connect(job.get(), &QGpgME::Job::jobProgress,
-            q, &Command::progress);
-#else
-    connect(job.get(), &QGpgME::Job::progress,
-            q, [this](const QString &, int current, int total) { Q_EMIT q->progress(current, total); });
-#endif
+    connect(job.get(), &QGpgME::Job::jobProgress, q, &Command::progress);
 
     QStringList fingerprints;
     fingerprints.reserve(keys.size());
@@ -289,10 +331,11 @@ void ExportCertificateCommand::Private::startExportJob(GpgME::Protocol protocol,
 void ExportCertificateCommand::Private::showError(const GpgME::Error &err)
 {
     Q_ASSERT(err);
-    const QString msg = i18n("<qt><p>An error occurred while trying to export "
-                             "the certificate:</p>"
-                             "<p><b>%1</b></p></qt>",
-                             Formatting::errorAsString(err));
+    const QString msg = i18n(
+        "<qt><p>An error occurred while trying to export "
+        "the certificate:</p>"
+        "<p><b>%1</b></p></qt>",
+        Formatting::errorAsString(err));
     error(msg, i18n("Certificate Export Failed"));
 }
 
@@ -337,8 +380,8 @@ void ExportCertificateCommand::Private::exportResult(const GpgME::Error &err, co
         return;
     }
     QSaveFile savefile(outFile);
-    //TODO: use KIO
-    const QString writeErrorMsg = i18n("Could not write to file %1.",  outFile);
+    // TODO: use KIO
+    const QString writeErrorMsg = i18n("Could not write to file %1.", outFile);
     const QString errorCaption = i18n("Certificate Export Failed");
     if (!savefile.open(QIODevice::WriteOnly)) {
         error(writeErrorMsg, errorCaption);
@@ -346,8 +389,7 @@ void ExportCertificateCommand::Private::exportResult(const GpgME::Error &err, co
         return;
     }
 
-    if (!write_complete(savefile, data) ||
-            !savefile.commit()) {
+    if (!write_complete(savefile, data) || !savefile.commit()) {
         error(writeErrorMsg, errorCaption);
     }
     finishedIfLastJob();
