@@ -8,31 +8,21 @@
 */
 
 #include <config-kleopatra.h>
+
 #include "appearanceconfigpage.h"
 
 #include "appearanceconfigwidget.h"
 
-
 #include <QVBoxLayout>
 
 using namespace Kleo;
 using namespace Kleo::Config;
 
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-AppearanceConfigurationPage::AppearanceConfigurationPage(QWidget *parent, const QVariantList &args)
-    : KCModule(parent, args)
-#else
-AppearanceConfigurationPage::AppearanceConfigurationPage(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
-    : KCModule(parent, data, args)
-#endif
+AppearanceConfigurationPage::AppearanceConfigurationPage(QObject *parent, const KPluginMetaData &data)
+    : KCModule(parent, data)
 {
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    auto lay = new QVBoxLayout(this);
-    mWidget = new AppearanceConfigWidget(this);
-#else
     auto lay = new QVBoxLayout(widget());
     mWidget = new AppearanceConfigWidget(widget());
-#endif
     lay->addWidget(mWidget);
 
     connect(mWidget, &AppearanceConfigWidget::changed, this, &Kleo::Config::AppearanceConfigurationPage::markAsChanged);
@@ -46,10 +36,11 @@ void AppearanceConfigurationPage::load()
 void AppearanceConfigurationPage::save()
 {
     mWidget->save();
-
 }
 
 void AppearanceConfigurationPage::defaults()
 {
     mWidget->defaults();
 }
+
+#include "moc_appearanceconfigpage.cpp"
