@@ -13,15 +13,17 @@
 
 #include "emailoperationspreferences.h"
 
+#include <crypto/decryptverifytask.h>
 #include <crypto/gui/resultitemwidget.h>
 
+#include <utils/gui-helper.h>
 #include <utils/scrollarea.h>
 
 #include <Libkleo/Stl_Util>
 
 #include <KLocalizedString>
-#include <QPushButton>
 #include <KStandardGuiItem>
+#include <QPushButton>
 
 #include <QLabel>
 #include <QVBoxLayout>
@@ -35,6 +37,7 @@ using namespace Kleo::Crypto::Gui;
 class ResultListWidget::Private
 {
     ResultListWidget *const q;
+
 public:
     explicit Private(ResultListWidget *qq);
 
@@ -43,11 +46,9 @@ public:
     void allTasksDone();
 
     void addResultWidget(ResultItemWidget *widget);
-    void setupSingle();
-    void setupMulti();
     void resizeIfStandalone();
 
-    std::vector< std::shared_ptr<TaskCollection> > m_collections;
+    std::vector<std::shared_ptr<TaskCollection>> m_collections;
     bool m_standaloneMode = false;
     int m_lastErrorItemIndex = 0;
     ScrollArea *m_scrollArea = nullptr;
@@ -57,12 +58,22 @@ public:
 };
 
 ResultListWidget::Private::Private(ResultListWidget *qq)
-    : q(qq),
-      m_collections()
+    : q(qq)
+    , m_collections()
 {
     m_layout = new QVBoxLayout(q);
     m_layout->setContentsMargins(0, 0, 0, 0);
     m_layout->setSpacing(0);
+
+    m_scrollArea = new ScrollArea;
+    m_scrollArea->setFocusPolicy(Qt::NoFocus);
+    auto scrollAreaLayout = qobject_cast<QBoxLayout *>(m_scrollArea->widget()->layout());
+    Q_ASSERT(scrollAreaLayout);
+    scrollAreaLayout->setContentsMargins(0, 0, 0, 0);
+    scrollAreaLayout->setSpacing(2);
+    scrollAreaLayout->addStretch();
+    m_layout->addWidget(m_scrollArea);
+
     m_progressLabel = new QLabel;
     m_progressLabel->setWordWrap(true);
     m_layout->addWidget(m_progressLabel);
@@ -73,9 +84,12 @@ ResultListWidget::Private::Private(ResultListWidget *qq)
     q->connect(m_closeButton, &QPushButton::clicked, q, &ResultListWidget::close);
     m_layout->addWidget(m_closeButton);
     m_closeButton->setVisible(false);
+    m_closeButton->setEnabled(false);
 }
 
-ResultListWidget::ResultListWidget(QWidget *parent, Qt::WindowFlags f) : QWidget(parent, f), d(new Private(this))
+ResultListWidget::ResultListWidget(QWidget *parent, Qt::WindowFlags f)
+    : QWidget(parent, f)
+    , d(new Private(this))
 {
 }
 
@@ -89,11 +103,6 @@ ResultListWidget::~ResultListWidget()
     prefs.save();
 }
 
-void ResultListWidget::Private::setupSingle()
-{
-    m_layout->addStretch();
-}
-
 void ResultListWidget::Private::resizeIfStandalone()
 {
     if (m_standaloneMode) {
@@ -101,32 +110,26 @@ void ResultListWidget::Private::resizeIfStandalone()
     }
 }
 
-void ResultListWidget::Private::setupMulti()
-{
-    if (m_scrollArea) {
-        return;    // already been here...
-    }
-
-    m_scrollArea = new ScrollArea;
-    m_scrollArea->setFocusPolicy(Qt::NoFocus);
-    Q_ASSERT(qobject_cast<QBoxLayout *>(m_scrollArea->widget()->layout()));
-    static_cast<QBoxLayout *>(m_scrollArea->widget()->layout())->setContentsMargins(0, 0, 0, 0);
-    static_cast<QBoxLayout *>(m_scrollArea->widget()->layout())->setSpacing(2);
-    static_cast<QBoxLayout *>(m_scrollArea->widget()->layout())->addStretch();
-    m_layout->insertWidget(0, m_scrollArea);
-}
-
 void ResultListWidget::Private::addResultWidget(ResultItemWidget *widget)
 {
     Q_ASSERT(widget);
-    Q_ASSERT(std::any_of(m_collections.cbegin(), m_collections.cend(),
-                       [](const std::shared_ptr<TaskCollection> &t) { return !t->isEmpty(); }));
+    Q_ASSERT(std::any_of(m_collections.cbegin(), m_collections.cend(), [](const std::shared_ptr<TaskCollection> &t) {
+        return !t->isEmpty();
+    }));
 
     Q_ASSERT(m_scrollArea);
     Q_ASSERT(m_scrollArea->widget());
-    Q_ASSERT(qobject_cast<QBoxLayout *>(m_scrollArea->widget()->layout()));
-    QBoxLayout &blay = *static_cast<QBoxLayout *>(m_scrollArea->widget()->layout());
-    blay.insertWidget(widget->hasErrorResult() ? m_lastErrorItemIndex++ : (blay.count() - 1), widget);
+    auto scrollAreaLayout = qobject_cast<QBoxLayout *>(m_scrollArea->widget()->layout());
+    Q_ASSERT(scrollAreaLayout);
+    // insert new widget after last widget showing error or before the trailing stretch
+    const auto insertIndex = widget->hasErrorResult() ? m_lastErrorItemIndex++ : scrollAreaLayout->count() - 1;
+    scrollAreaLayout->insertWidget(insertIndex, widget);
+    if (insertIndex == 0) {
+        forceSetTabOrder(m_scrollArea->widget(), widget);
+    } else {
+        auto previousResultWidget = qobject_cast<ResultItemWidget *>(scrollAreaLayout->itemAt(insertIndex - 1)->widget());
+        QWidget::setTabOrder(previousResultWidget, widget);
+    }
 
     widget->show();
     resizeIfStandalone();
@@ -145,49 +148,57 @@ void ResultListWidget::Private::allTasksDone()
 void ResultListWidget::Private::result(const std::shared_ptr<const Task::Result> &result)
 {
     Q_ASSERT(result);
-    Q_ASSERT(std::any_of(m_collections.cbegin(), m_collections.cend(),
-                       [](const std::shared_ptr<TaskCollection> &t) { return !t->isEmpty(); }));
+    Q_ASSERT(std::any_of(m_collections.cbegin(), m_collections.cend(), [](const std::shared_ptr<TaskCollection> &t) {
+        return !t->isEmpty();
+    }));
     auto wid = new ResultItemWidget(result);
     q->connect(wid, &ResultItemWidget::linkActivated, q, &ResultListWidget::linkActivated);
     q->connect(wid, &ResultItemWidget::closeButtonClicked, q, &ResultListWidget::close);
+
+    const auto viewableContentType = result->viewableContentType();
+
+    if (viewableContentType == Task::Result::ContentType::Mime || viewableContentType == Task::Result::ContentType::Mbox) {
+        wid->setShowButton(i18nc("@action:button", "Show Email"), true);
+        q->connect(wid, &ResultItemWidget::showButtonClicked, q, [this, result] {
+            Q_EMIT q->showButtonClicked(result);
+        });
+    }
+
     addResultWidget(wid);
 }
 
 bool ResultListWidget::isComplete() const
 {
-    return std::all_of(d->m_collections.cbegin(), d->m_collections.cend(),
-                       std::mem_fn(&TaskCollection::allTasksCompleted));
+    return std::all_of(d->m_collections.cbegin(), d->m_collections.cend(), std::mem_fn(&TaskCollection::allTasksCompleted));
 }
 
 unsigned int ResultListWidget::totalNumberOfTasks() const
 {
-    return kdtools::accumulate_transform(d->m_collections.cbegin(),
-                                         d->m_collections.cend(),
-                                         std::mem_fn(&TaskCollection::size), 0U);
+    return kdtools::accumulate_transform(d->m_collections.cbegin(), d->m_collections.cend(), std::mem_fn(&TaskCollection::size), 0U);
 }
 
 unsigned int ResultListWidget::numberOfCompletedTasks() const
 {
-    return kdtools::accumulate_transform(d->m_collections.cbegin(), d->m_collections.cend(),
-                                         std::mem_fn(&TaskCollection::numberOfCompletedTasks), 0U);
+    return kdtools::accumulate_transform(d->m_collections.cbegin(), d->m_collections.cend(), std::mem_fn(&TaskCollection::numberOfCompletedTasks), 0U);
 }
 
 void ResultListWidget::setTaskCollection(const std::shared_ptr<TaskCollection> &coll)
 {
-    //clear(); ### PENDING(marc) implement
+    // clear(); ### PENDING(marc) implement
     addTaskCollection(coll);
 }
 
 void ResultListWidget::addTaskCollection(const std::shared_ptr<TaskCollection> &coll)
 {
-    Q_ASSERT(coll); Q_ASSERT(!coll->isEmpty());
+    Q_ASSERT(coll);
+    Q_ASSERT(!coll->isEmpty());
     d->m_collections.push_back(coll);
-    connect(coll.get(), SIGNAL(result(std::shared_ptr<const Kleo::Crypto::Task::Result>)),
-            this, SLOT(result(std::shared_ptr<const Kleo::Crypto::Task::Result>)));
-    connect(coll.get(), SIGNAL(started(std::shared_ptr<Kleo::Crypto::Task>)),
-            this, SLOT(started(std::shared_ptr<Kleo::Crypto::Task>)));
+    connect(coll.get(),
+            SIGNAL(result(std::shared_ptr<const Kleo::Crypto::Task::Result>)),
+            this,
+            SLOT(result(std::shared_ptr<const Kleo::Crypto::Task::Result>)));
+    connect(coll.get(), SIGNAL(started(std::shared_ptr<Kleo::Crypto::Task>)), this, SLOT(started(std::shared_ptr<Kleo::Crypto::Task>)));
     connect(coll.get(), SIGNAL(done()), this, SLOT(allTasksDone()));
-    d->setupMulti();
     setStandaloneMode(d->m_standaloneMode);
 }
 
@@ -206,6 +217,7 @@ void ResultListWidget::setStandaloneMode(bool standalone)
         return;
     }
     d->m_closeButton->setVisible(standalone);
+    d->m_closeButton->setEnabled(standalone);
     d->m_progressLabel->setVisible(standalone);
 }
 
