@@ -16,30 +16,31 @@
 
 #include "certifywidget.h"
 
+#include <Libkleo/Algorithm>
 #include <Libkleo/Formatting>
+#include <Libkleo/KeyHelpers>
 #include <Libkleo/Stl_Util>
 
-#include <KLocalizedString>
-#include <KStandardGuiItem>
-#include <KSharedConfig>
 #include <KConfigGroup>
+#include <KLocalizedString>
 #include <KMessageBox>
+#include <KSharedConfig>
+#include <KStandardGuiItem>
 
-#include <QVBoxLayout>
 #include <QDialogButtonBox>
 #include <QKeyEvent>
 #include <QPushButton>
-#include <QToolTip>
+#include <QVBoxLayout>
 
 #include <gpg-error.h>
 
-
 using namespace GpgME;
 using namespace Kleo;
 
 CertifyCertificateDialog::CertifyCertificateDialog(QWidget *p, Qt::WindowFlags f)
     : QDialog(p, f)
 {
+    setWindowTitle(i18nc("@title:window", "Certify Certificates"));
     setWindowFlags(windowFlags() & (~Qt::WindowContextHelpButtonHint));
 
     // Setup GUI
@@ -48,8 +49,7 @@ CertifyCertificateDialog::CertifyCertificateDialog(QWidget *p, Qt::WindowFlags f
     mainLay->addWidget(mCertWidget);
 
     auto buttonBox = new QDialogButtonBox{this};
-    buttonBox->setStandardButtons(QDialogButtonBox::Cancel |
-                                  QDialogButtonBox::Ok);
+    buttonBox->setStandardButtons(QDialogButtonBox::Cancel | QDialogButtonBox::Ok);
     const auto okButton = buttonBox->button(QDialogButtonBox::Ok);
     KGuiItem::assign(okButton, KStandardGuiItem::ok());
     okButton->setText(i18n("Certify"));
@@ -60,11 +60,11 @@ CertifyCertificateDialog::CertifyCertificateDialog(QWidget *p, Qt::WindowFlags f
     mainLay->addWidget(buttonBox);
 
     okButton->setEnabled(mCertWidget->isValid());
-    connect(mCertWidget, &CertifyWidget::changed, this, [this, okButton] () {
+    connect(mCertWidget, &CertifyWidget::changed, this, [this, okButton]() {
         okButton->setEnabled(mCertWidget->isValid());
     });
 
-    KConfigGroup cfgGroup(KSharedConfig::openStateConfig(), "CertifyDialog");
+    KConfigGroup cfgGroup(KSharedConfig::openStateConfig(), QStringLiteral("CertifyDialog"));
     const auto size = cfgGroup.readEntry("Size", QSize{640, 480});
     if (size.isValid()) {
         resize(size);
@@ -73,15 +73,28 @@ CertifyCertificateDialog::CertifyCertificateDialog(QWidget *p, Qt::WindowFlags f
 
 CertifyCertificateDialog::~CertifyCertificateDialog()
 {
-    KConfigGroup cfgGroup(KSharedConfig::openStateConfig(), "CertifyDialog");
+    KConfigGroup cfgGroup(KSharedConfig::openStateConfig(), QStringLiteral("CertifyDialog"));
     cfgGroup.writeEntry("Size", size());
     cfgGroup.sync();
 }
 
-void CertifyCertificateDialog::setCertificateToCertify(const Key &key)
+void CertifyCertificateDialog::setCertificateToCertify(const Key &key, const std::vector<GpgME::UserID> &uids)
 {
+    Q_ASSERT(Kleo::all_of(uids, [key](const auto &uid) {
+        return Kleo::userIDBelongsToKey(uid, key);
+    }));
     setWindowTitle(i18nc("@title:window arg is name, email of certificate holder", "Certify Certificate: %1", Formatting::prettyName(key)));
-    mCertWidget->setTarget(key);
+    mCertWidget->setCertificate(key, uids);
+}
+
+void CertifyCertificateDialog::setCertificatesToCertify(const std::vector<GpgME::Key> &keys)
+{
+    mCertWidget->setCertificates(keys);
+}
+
+void CertifyCertificateDialog::setGroupName(const QString &name)
+{
+    setWindowTitle(i18nc("@title:window Certify Certificate Group <group name>", "Certify Certificate Group %1", name));
 }
 
 bool CertifyCertificateDialog::exportableCertificationSelected() const
@@ -99,11 +112,6 @@ QString CertifyCertificateDialog::trustSignatureDomain() const
     return mCertWidget->trustSignatureDomain();
 }
 
-bool CertifyCertificateDialog::nonRevocableCertificationSelected() const
-{
-    return false;
-}
-
 Key CertifyCertificateDialog::selectedSecretKey() const
 {
     return mCertWidget->secKey();
@@ -140,24 +148,9 @@ void CertifyCertificateDialog::accept()
         return;
     }
 
-    KConfigGroup conf(KSharedConfig::openConfig(), "CertifySettings");
-    const auto lastKey = mCertWidget->secKey();
-    if (!lastKey.isNull()) {
-        conf.writeEntry("LastKey", lastKey.primaryFingerprint());
-    }
-    conf.writeEntry("ExportCheckState", mCertWidget->exportableSelected());
-    conf.writeEntry("PublishCheckState", mCertWidget->publishSelected());
+    mCertWidget->saveState();
 
     QDialog::accept();
 }
 
-void CertifyCertificateDialog::keyPressEvent(QKeyEvent *e)
-{
-    // if Escape is pressed while a tool tip is shown, then close the tool tip but not the dialog
-    if (e->matches(QKeySequence::Cancel) && QToolTip::isVisible()) {
-        QToolTip::hideText();
-        return;
-    }
-
-    QDialog::keyPressEvent(e);
-}
+#include "moc_certifycertificatedialog.cpp"
