@@ -27,8 +27,7 @@ class ExpiryDialog : public QDialog
 {
     Q_OBJECT
 public:
-    enum class Mode
-    {
+    enum class Mode {
         UpdateCertificateWithSubkeys,
         UpdateCertificateWithoutSubkeys,
         UpdateIndividualSubkey,
@@ -43,6 +42,8 @@ public:
     void setUpdateExpirationOfAllSubkeys(bool update);
     bool updateExpirationOfAllSubkeys() const;
 
+    void accept() override;
+
 protected:
     void showEvent(QShowEvent *event) override;
 
@@ -53,4 +54,3 @@ private:
 
 }
 }
-
